@@ -238,14 +238,15 @@ def _fill_param_row(ws, row_idx, param):
     ).alignment = Alignment(
         wrap_text=True,
     )
+    events = param.get('events', {})
     ws.cell(
-        row_idx, 13, value=param['events']['created']['at'],
+        row_idx, 13, value=events.get('created', {}).get('at', '-'),
     ).alignment = Alignment(
         horizontal='left',
         vertical='top',
     )
     ws.cell(
-        row_idx, 14, value=param['events'].get('updated', {}).get('at'),
+        row_idx, 14, value=events.get('updated', {}).get('at', '-'),
     ).alignment = Alignment(
         horizontal='left',
         vertical='top',
@@ -292,12 +293,15 @@ def _fill_template_row(ws, row_idx, template):
     ws.cell(row_idx, 6, value=template['body']).alignment = Alignment(
         wrap_text=True,
     )
-    ws.cell(row_idx, 7, value=template['events']['created']['at']).alignment = Alignment(
+    events = template.get('events', {})
+    ws.cell(
+        row_idx, 7, value=events.get('created', {}).get('at', '-'),
+    ).alignment = Alignment(
         horizontal='left',
         vertical='top',
     )
     ws.cell(
-        row_idx, 8, value=template['events'].get('updated', {}).get('at'),
+        row_idx, 8, value=events.get('updated', {}).get('at', '-'),
     ).alignment = Alignment(
         horizontal='left',
         vertical='top',
@@ -312,8 +316,9 @@ def _fill_action_row(ws, row_idx, action):
     ws.cell(row_idx, 5, value=action['title'])
     ws.cell(row_idx, 6, value=action['description'])
     ws.cell(row_idx, 7, value=action['scope'])
-    ws.cell(row_idx, 8, value=action['events']['created']['at'])
-    ws.cell(row_idx, 9, value=action['events'].get('updated', {}).get('at'))
+    events = action.get('events', {})
+    ws.cell(row_idx, 8, value=events.get('created', {}).get('at', '-'))
+    ws.cell(row_idx, 9, value=events.get('updated', {}).get('at', '-'))
 
 
 def _fill_configuration_row(ws, row_idx, configuration, conf_id):
@@ -351,8 +356,9 @@ def _fill_item_row(ws, row_idx, item):
     ws.cell(row_idx, 9, value=period)
     ws.cell(row_idx, 10, value=_calculate_commitment(item))
     ws.cell(row_idx, 11, value=item['status'])
-    ws.cell(row_idx, 12, value=item['events']['created']['at'])
-    ws.cell(row_idx, 13, value=item['events'].get('updated', {}).get('at'))
+    events = item.get('events', {})
+    ws.cell(row_idx, 12, value=events.get('created', {}).get('at', '-'))
+    ws.cell(row_idx, 13, value=events.get('updated', {}).get('at', '-'))
 
 
 def _calculate_configuration_id(configuration):
